How to contribute
=================

We want tsfresh to become the biggest archive of feature extraction methods in python. To achieve this goal, we need
your help!

So if you want to add one or two interesting feature calculators, implement a new feature selection process
or just fix 1-2 typos, your help is appreciated.

If you want to help, just create a pull request on our github page. If you are not familiar with the versioning tool git
you can contact us by email.

We are looking forward to hear from you! =)